==> ja-gorua-0.13b.tgz: lib/ruby/site_ruby/1.6/connect2ch.rb <==
#ΥեGPLդƤޤ.
#Υץ̵ݾڤǤ.
# connect2ch.rb  
CONNECT2CH_VERSION = 0.11
# ջ  haruyama@unixuser.org
# $Id: connect2ch.rb,v 1.31 2002/05/01 11:46:42 haruyama Exp $

# EUC
# ޤŬ

#require 'kconv'
require 'nkf'
require 'net/http'
require 'timeout'
begin
  require 'zlib'
  $connect_2ch_gzip = true
rescue LoadError
  #
  $connect_2ch_gzip = false
end

$connect2ch_config={
  'proxy_addr' => nil,
  'proxy_port' => nil,
  'http_get_timeout' => 60,
  'user_agent' => "connect2ch.rb #{CONNECT2CH_VERSION}"
}



def parse_http_url(url)
  # httpsftp ̤˰
  if %r!^h?ttps?://(\S*?)(?::(\d+))?(/\S*)?$! =~  url
    host = $1
    if $2
      port = Integer($2)
    else
      port = 80
    end
    path = $3
    return host,port,path
  else
    return nil,nil,nil
  end

end


module PostMessage2ch

  def http_encode(str)
    return str.gsub(/[^a-zA-Z0-9_.-]/n){sprintf("%%%02X",$&.unpack("C")[0]) }
  end

  def quote(str)
#ޤʤ
    return str
  end

  def convert_and_encode(str)
#    str = Kconv::kconv(str,Kconv::SJIS,Kconv::EUC)
    str=NKF::nkf('-sxE',str)
    return http_encode(str)
  
  end


  def post_message(thread,name,mailto,message)
    host = thread.get_host
    port = thread.get_port
    path = thread.get_base_path + "test/bbs.cgi"
    bbs = thread.get_bbs
    key = thread.get_key
    if port == 80
      tmp  = "http://#{host}/"
    else
      tmp  = "http://#{host}:#{port}/"
    end
    referer = tmp + "#{bbs}/index2.html"
    return post_message_(host,port,path,referer,bbs,key,name,mailto,message)
  end

  def post_message_(host,port,path,referer,bbs,key,name,mailto,message)
    kakikomu='񤭤'
    kakikomu = convert_and_encode(kakikomu)
    name = convert_and_encode(name)
    mailto = convert_and_encode(mailto)
    message = convert_and_encode(message)

#    time
    time = Time.now.to_i.to_s


    header = {}
    header['User-Agent']= $connect2ch_config['user_agent']
    header['Referer']= referer
    header['Content-Type']= 'application/x-www-form-urlencoded'
    header['Cookie']= "NAME=#{name};MAIL=#{mailto}"
      
#    Net::HTTP.start(host,port ) {|http|
      # Thanks: >>159
      Net::HTTP.start(host,port,$connect2ch_config['proxy_addr'],$connect2ch_config['proxy_port']){ |http|
      begin
	response , = http.post( path,
			       "submit=#{kakikomu}&FROM=#{name}&mail=#{mailto}&MESSAGE=#{message}&bbs=#{bbs}&key=#{key}&time=#{time}",
			     header)


# ʤˤԤ return false
	if response.code == "200"
	  return true
	else
#	  STDERR.print Kconv::kconv(response.body,Kconv::EUC,Kconv::SJIS)
	  STDERR.print NKF::nkf('-exS',response.body)
	  return false
	end
      rescue Net::ProtoRetriableError
# 쥯ȥڡȽФ褦
	return true
      rescue
	print "㳰ȯ񤭤ޤ줿ɤ狼ޤ\n"
	return false
      end
    }
  end


end


module HTTPGetGzip


  def http_get_file(host,port,path,filename,gzip=true)

    header = {}
    if gzip
      gzip =  $connect_2ch_gzip
    end

    header['User-Agent']= $connect2ch_config['user_agent']
    
    if gzip
      header['Accept-Encoding']='gzip'
    end
# Thanks >>7
    file = nil
    begin
#      timeout(60){
#	Net::HTTP.start(host,port,$proxy_addr,$proxy_port){ |http|
      timeout($connect2ch_config['http_get_timeout']){
	Net::HTTP.start(host,port,$connect2ch_config['proxy_addr'],$connect2ch_config['proxy_port']){ |http|
	  response , = http.get(path,header)
	  begin
	    file = open( filename, 'w+' )
	  rescue 
	    STDERR.print "#{filename}ޤǤ\n"    
	    return nil
	  end
	  file.write response.body
	  file.rewind
	  if  gzip == true && response['Content-Encoding'] == "gzip"
	    begin 
	      file=Zlib::GzipReader.new(file)
	    rescue
	    end
	  end
	  return file	    
	}
      }
    rescue Net::ProtoRetriableError => err
#      p err
      if m = %r<http://([^/]+)>.match( err.response['location'] ) then
	# 餯̣ʤ
	host = m[1].strip
	path = m.post_match
#	p host
#	p path
	retry
      end
    rescue => evar
      p evar
      STDERR.print "եμ˼ԡ\n"    
      return nil
    end
  end
end


module GetThread2ch
  include HTTPGetGzip

  def file_change(from,to)
    File.rename(from,to)

    begin
      file =  open(to,'r')
    rescue
      STDERR.print "#{to}ޤǤ\n"    
      return nil
    end


    begin
      file = Zlib::GzipReader.new(file)
    rescue
    end
    return file
  end

  def get_thread_file(thread,size=0,num_of_statements=0)
    host = thread.get_host
    port = thread.get_port
    path = thread.get_path
    filename = thread.get_filename
    file = thread.get_file    
    dat=  thread.get_dat
    return get_thread_file_(host,port,path,filename,file,dat,size,num_of_statements)
  end


  def get_thread_file_(host,port,path,filename,file,dat=nil,size=0,num_of_statements=0)

    if file 
      file.rewind
    else
      if File.exist?(filename)
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil,nil
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
	  # gzipǤʤ
	end
      end
    end


    #ʬɤߤѽ ʬνϤʤꤤ

    if size <=0 && num_of_statements <=0
      size =0
      num_of_statements=0
      if file 
	file.rewind
	begin
	  file.each{ |line|
#	    line=Kconv::kconv(line,Kconv::EUC,Kconv::SJIS)
	    line=NKF::nkf('-exS',line)
	    if /^(?:\+OK|-INCR)\s+(\d+)/ =~ line
	      size+=Integer($1)
	    else
	      num_of_statements+=1
	    end

	  }
	rescue Zlib::StreamError
	  STDERR.print "Zlib::StreamError Ǥɤߤߤߤޤ\n"
#	  return nil
	  size=0
	  num_of_statements=0
	rescue
	  STDERR.print "ͽʤ顼Ǥɤߤߤߤޤ\n"
#	  return nil
	  size=0
	  num_of_statements=0
	end

      end

    end



    if dat
      # datľɤ
      return get_thread_file_via_dat(host,port,path,filename),num_of_statements
    else
      return get_thread_file_via_read_cgi(host,port,path,filename,file,size,num_of_statements)
    end

  end

#̤ƥ
  def get_thread_file_via_dat(host,port,path,filename)
    
    file = http_get_file(host,port,path,filename)
    if file ==nil
      STDERR.print "datեμ˼Ԥޤ\n"
      if File.exist?(filename)
	STDERR.print "åѤޤ\n"
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
	  # gzipǤʤ
	end
      else
	STDERR.print "å⤢ޤ\n"
	return nil
      end

    end
    return file
    
  end

  def get_thread_file_via_read_cgi(host,port,path,filename,file,size=0,num_of_statements=0)


    if path =~ /\?/
      path += "&raw=#{num_of_statements}.#{size}"
    else
      path += "?raw=#{num_of_statements}.#{size}"
    end

    tmp_filename = filename+"_tmp"
    tmp_file = http_get_file(host,port,path,tmp_filename)

    if tmp_file ==nil
      STDERR.print "threadեμ˼Ԥޤ\n"
      if file
	STDERR.print "åѤޤ.\n"
	return file,nil
      else
	STDERR.print "å⤢ޤ.\n"
	return nil,nil
      end
    end
    
    line= tmp_file.gets
#    line=Kconv::kconv(line,Kconv::EUC,Kconv::SJIS)
    line=NKF::nkf('-exS',line)
    #TODO: 0ΤȤɲäʤ褦ˤ

    if /^\+OK\s+(\d+)/ =~ line
      if $1 == "0"
	tmp_file.close
	File.unlink(tmp_filename)
	return file,num_of_statements
      end

      tmp_file.rewind
      if file 

	file.rewind
	contents = file.read
	file.close
	# fileʤ餺gzipǰ̤ƤȤϤʤΤ
	# ݤʤȤ򤹤
	# ޤ GzipReaderˤrewindϤäƤseekϤʤ
	# (gzipΥإå եåΤ)
	begin
	  file = open(filename,'w')
	rescue
	  STDERR.print "#{filename}ޤǤ\n"    
	  return nil,nil
	end

	file = Zlib::GzipWriter.new(file)
	
	file.write  contents
	file.write  tmp_file.read
	
	file.close
	tmp_file.close

	File.unlink(tmp_filename)

	begin
	  file =  open(filename,'r')
	rescue 
	  STDERR.print "#{filename}ޤǤ\n"    
	  return nil,nil
	end
	  

	file = Zlib::GzipReader.new(file)
      else
	tmp_file.close
	file = file_change(tmp_filename,filename)
      end
    elsif  /^\-INCR/ =~ line
      if file
	file.close
      end
      tmp_file.close

      file = file_change(tmp_filename,filename)
    else
# Thanks: 136
      STDERR.print "threadե˰۾郎ޤdatƤǽ⤤Ǥ\n"
      tmp_file.close
      File.unlink(tmp_filename)
      return file,nil
    end
    return file,num_of_statements
  end


end

module  GetBoardSubject2ch
  include HTTPGetGzip


  def get_board_subject_file(board)
    host = board.get_host
    port = board.get_port
    path = board.get_path
    filename = board.get_filename

    if board.get_dat
      return get_board_subject_file_dat(host,port,path,filename)
    else
      return get_board_subject_file_read_cgi(host,port,path,filename)
    end
  end

  def get_board_subject_file_read_cgi(host,port,path,filename,ls=nil)
    # ls̤ƥ
    if %r!^(.*)(/[^/]+/)$! =~ path
      path2 = $1 + "/test/read.cgi" + $2 + "?raw=0.0"
      if ls 
	path2 += "&ls=#{ls}"
      end
    else
      return get_board_subject_file_(host,port,path,filename,nil)
    end
    file=http_get_file(host,port,path2,filename)
    return get_board_subject_file_(host,port,path,filename,file)
  end

  def get_board_subject_file_dat(host,port,path,filename)
    
    path2 = path + "subject.txt"
    file=http_get_file(host,port,path2,filename)
    return get_board_subject_file_(host,port,path,filename,file)
  end

  def get_board_subject_file_(host,port,path,filename,file)
    # Thanks >>8:
    if file == nil
      STDERR.print "subjectեμ˼Ԥޤ\n"
      if File.exist?(filename)
	STDERR.print "åѤޤ.\n"
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
         # gzipǤʤ
	end
	return file
      else
	STDERR.print "å⤢ޤ.\n"
      end

      return nil
    end

    

    return file

  end

end

#̤ƥ
module  GetBoardInfo2ch
  include HTTPGetGzip

  def get_board_info(host,port,path)
#     Net::HTTP.start(host,port,$proxy_addr,$proxy_port){ |http|
    Net::HTTP.start(host,port,$connect2ch_config['proxy_addr'],$connect2ch_config['proxy_port']){ |http|
      response,= http.get(path,nil)

      if response.code == "200"
	return response.body
      else
	return nil
      end
    }
  end

  def parse_board_info_html(body)

    flag = 0
    info = []
    body.each { |line|
      while true
#	line=Kconv::toeuc(line)
	line=NKF::nkf('-ex',line)
#	p line
	line.strip!
	if /^<B>(.*?)<\/B><BR>(.*)$/i =~  line
	  tmp ="C " + $1 +"\n"
	  if "å" == $1
	    return info
	  elsif "ޤ££" == $1
	    flag=0
	  else
	    flag=1
	    info << tmp
	  end
	  line = $2
	elsif /^<A HREF=([^> ]*).*?>(.*?)<\/A>(.*)$/i =~ line
	  url = $1
	  board = $2
	  line = $3

	  if url != "http://www.machibbs.com/" && url != "http://dempa.gozans.com/"
	    if flag ==1
	      tmp = "B " 
	    elsif flag ==2
	      tmp = "A " 
	    end
	    if flag > 0 
#	      tmp1 = $1
#	      tmp2 = $2
#	      tmp2.gsub!(/<br>/i," ")
#	      board.gsub!(/<br>/i," ")
	      tmp += url + " " + board.gsub(/<br>/i," ")  + "\n"
	      info << tmp
	    end
	  end
	elsif /^.+?((<B>|<A).*)$/i =~ line
	  line = $1
	else
	  break
	end
      end
    }
    return info
  end

end

==> ja-gorua-0.14a.tgz: lib/ruby/site_ruby/1.6/connect2ch.rb <==
#ΥեGPLդƤޤ.
#Υץ̵ݾڤǤ.
# connect2ch.rb  
CONNECT2CH_VERSION = 0.13
# ջ  haruyama@unixuser.org
# $Id: connect2ch.rb,v 1.38 2002/06/01 03:45:37 haruyama Exp $

# EUC
# ޤŬ

#require 'kconv'
require 'nkf'
require 'net/http'
require 'timeout'
begin
  require 'zlib'
  $connect_2ch_gzip = true
rescue LoadError
  #
  $connect_2ch_gzip = false
end

$connect2ch_config={
  'get_proxy_addr' => nil,
  'get_proxy_port' => nil,
  'post_proxy_addr' => nil,
  'post_proxy_port' => nil,
  'http_get_timeout' => 60,
  'user_agent' => "connect2ch.rb #{CONNECT2CH_VERSION}"
}



def parse_http_url(url)
  # httpsftp ̤˰
  if %r!^h?ttps?://(\S*?)(?::(\d+))?(/\S*)?$! =~  url
    host = $1
    if $2
      port = Integer($2)
    else
      port = 80
    end
    path = $3
    return host,port,path
  else
    return nil,nil,nil
  end

end


module PostMessage2ch

  def http_encode(str)
    return str.gsub(/[^a-zA-Z0-9_.-]/n){sprintf('%%%02X',$&.unpack('C')[0]) }
  end

  def quote(str)
#ޤʤ
    return str
  end

  def convert_and_encode(str)
#    str = Kconv::kconv(str,Kconv::SJIS,Kconv::EUC)
    str=NKF::nkf('-sxE',str)
    return http_encode(str)
  
  end


  def post_message(thread,name,mailto,message)
    host = thread.get_host
    port = thread.get_port
    path = thread.get_base_path + 'test/bbs.cgi'
    bbs = thread.get_bbs
    key = thread.get_key
    if port == 80
      tmp  = "http://#{host}/"
    else
      tmp  = "http://#{host}:#{port}/"
    end
    referer = tmp + "#{bbs}/index2.html"
    return post_message_(host,port,path,referer,bbs,key,name,mailto,message)
  end

  def post_message_(host,port,path,referer,bbs,key,name,mailto,message)
    kakikomu='񤭤'
    kakikomu = convert_and_encode(kakikomu)
    name = convert_and_encode(name)
    mailto = convert_and_encode(mailto)
    message = convert_and_encode(message)

#    time
    time = Time.now.to_i.to_s


    header = {}
    header['User-Agent']= $connect2ch_config['user_agent']
    header['Referer']= referer
    header['Content-Type']= 'application/x-www-form-urlencoded'
    header['Cookie']= "NAME=#{name};MAIL=#{mailto}"
      
#    Net::HTTP.start(host,port ) {|http|
      # Thanks: >>159
      Net::HTTP.start(host,port,$connect2ch_config['post_proxy_addr'],$connect2ch_config['post_proxy_port']){ |http|
      begin
	response , = http.post( path,
			       "submit=#{kakikomu}&FROM=#{name}&mail=#{mailto}&MESSAGE=#{message}&bbs=#{bbs}&key=#{key}&time=#{time}",
			     header)


# ʤˤԤ return false

	body = NKF::nkf('-exS',response.body)
	if response.code == '200'
	  # navi2ch 1.5.1 
	  if /񤭤ߤޤ/ =~ body
	    return true, '񤭹(1)'
	  elsif /ţңңϣҡ([^<]+)/ =~ body
	    STDERR.print "񤭤ߥ顼: #{$1}\n"
	    return false,"񤭹߼: #{$1}"
	  else
	    STDERR.print "ν񤭤ߥ顼\n"
	    STDERR.print body
	    return false,'ν񤭤ߥ顼(1)'
	  end

	else
#	  STDERR.print Kconv::kconv(response.body,Kconv::EUC,Kconv::SJIS)
	  STDERR.print body
	  return false,'ν񤭤ߥ顼(2)'
	end
      rescue Net::ProtoRetriableError
# 쥯ȥڡȽФ褦
=begin
	if m = %r<http://([^/]+)>.match( err.response['location'] ) then
	  host = m[1].strip
	  path = m.post_match
	  retry
	else
	  print "쥯ȥڡ񤭤ޤ줿ɤ狼ޤ\n"
	  return false
	end
=end
	# Ƚ񤭤ޤ줿쥯ȥڡˤä
	# 
	# Τ鼺Ԥˤʤ
	return true, '񤭹(2)'
#	return true
      rescue
	print "㳰ȯ񤭤ޤ줿ɤ狼ޤ\n"
	return false,'㳰ȯ񤭤ޤ줿ɤ狼ޤ'
      end
    }
  end


end


module HTTPGetGzip


  def http_get_file(host,port,path,filename,gzip=true)

    header = {}
    if gzip
      gzip =  $connect_2ch_gzip
    end

    header['User-Agent']= $connect2ch_config['user_agent']
    
    if gzip
      header['Accept-Encoding']='gzip'
    end
# Thanks >>7
    file = nil
    begin
#      timeout(60){
#	Net::HTTP.start(host,port,$proxy_addr,$proxy_port){ |http|
      timeout($connect2ch_config['http_get_timeout']){
	Net::HTTP.start(host,port,$connect2ch_config['get_proxy_addr'],$connect2ch_config['get_proxy_port']){ |http|
	  response , = http.get(path,header)
	  begin
	    file = open( filename, 'w+' )
	  rescue 
	    STDERR.print "#{filename}ޤǤ\n"    
	    return nil,"#{filename}ޤǤ"
	  end
	  file.write response.body
	  file.rewind
	  if  gzip == true && response['Content-Encoding'] == 'gzip'
	    begin 
	      file=Zlib::GzipReader.new(file)
	    rescue
	    end
	  end
	  return file,nil	    
	}
      }
    rescue Net::ProtoRetriableError => err
#      p err
      if m = %r<http://([^/]+)>.match( err.response['location'] ) then
	# 餯̣ʤ
	host = m[1].strip
	path = m.post_match
#	p host
#	p path
	retry
      end
    rescue Errno::ECONNREFUSED
      STDERR.print "Errno::ECONNREFUSED ޤ\n"    
      STDERR.print "ФʤProxyưƤʤΤ⤷ޤ\n"    
      STDERR.print "եμ˼ԡ\n"    
      return nil,'եμ˼(1)'
    rescue => evar
      p evar
      STDERR.print "եμ˼ԡ\n"    
      return nil,'եμ˼(2)'
    end
  end
end


module GetThread2ch
  include HTTPGetGzip

  def file_change(from,to)
    File.rename(from,to)

    begin
      file =  open(to,'r')
    rescue
      STDERR.print "#{to}ޤǤ\n"    
      return nil,'#{to}ޤǤ'
    end


    begin
      file = Zlib::GzipReader.new(file)
    rescue
    end
    return file,nil
  end

  def get_thread_file(thread,size=0,num_of_statements=0)
    host = thread.get_host
    port = thread.get_port
    path = thread.get_path
    filename = thread.get_filename
    file = thread.get_file    
    dat=  thread.get_dat
    return get_thread_file_(host,port,path,filename,file,dat,size,num_of_statements)
  end


  def get_thread_file_(host,port,path,filename,file,dat=nil,size=0,num_of_statements=0)

    if file 
      file.rewind
    else
      if File.exist?(filename)
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil,nil
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
	  # gzipǤʤ
	end
      end
    end


    #ʬɤߤѽ ʬνϤʤꤤ

    if size <=0 && num_of_statements <=0
      size =0
      num_of_statements=0
      if file 
	file.rewind
	begin
	  file.each{ |line|
#	    line=Kconv::kconv(line,Kconv::EUC,Kconv::SJIS)
	    line=NKF::nkf('-exS',line)
	    if /^(?:\+OK|-INCR)\s+(\d+)/ =~ line
	      size+=Integer($1)
	    else
	      num_of_statements+=1
	    end

	  }
	rescue Zlib::StreamError
	  STDERR.print "Zlib::StreamError Ǥɤߤߤߤޤ\n"
#	  return nil
	  size=0
	  num_of_statements=0
	rescue
	  STDERR.print "ͽʤ顼Ǥɤߤߤߤޤ\n"
#	  return nil
	  size=0
	  num_of_statements=0
	end

      end

    end



    if dat
      # datľɤ
      return get_thread_file_via_dat(host,port,path,filename),num_of_statements
    else
      return get_thread_file_via_read_cgi(host,port,path,filename,file,size,num_of_statements)
    end

  end

#̤ƥ
  def get_thread_file_via_dat(host,port,path,filename)
    
    file,error = http_get_file(host,port,path,filename)
    if file ==nil
      STDERR.print "datեμ˼Ԥޤ\n"
      if File.exist?(filename)
	STDERR.print "åѤޤ\n"
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
	  # gzipǤʤ
	end
      else
	STDERR.print "å⤢ޤ\n"
	return nil
      end

    end
    return file
    
  end

  def get_thread_file_via_read_cgi(host,port,path,filename,file,size=0,num_of_statements=0)


    if path =~ /\?/
      path += "&raw=#{num_of_statements}.#{size}"
    else
      path += "?raw=#{num_of_statements}.#{size}"
    end

    tmp_filename = filename+"_tmp"
    tmp_file,error= http_get_file(host,port,path,tmp_filename)

    if tmp_file ==nil
      STDERR.print "threadեμ˼Ԥޤ\n"
      if file
	STDERR.print "åѤޤ.\n"
	return file,nil,'threadեμ˼ԤޤåѤޤ'
      else
	STDERR.print "å⤢ޤ.\n"
	return nil,nil,'threadեμ˼Ԥޤå⤢ޤ'
      end
    end
    
    line= tmp_file.gets
#    line=Kconv::kconv(line,Kconv::EUC,Kconv::SJIS)
    line=NKF::nkf('-exS',line)
    #TODO: 0ΤȤɲäʤ褦ˤ

    if /^\+OK\s+(\d+)/ =~ line
      if $1 == '0'
	tmp_file.close
	File.unlink(tmp_filename)
	return file,num_of_statements,nil
      end

      tmp_file.rewind
      if file 

	file.rewind
	contents = file.read
	file.close
	# fileʤ餺gzipǰ̤ƤȤϤʤΤ
	# ݤʤȤ򤹤
	# ޤ GzipReaderˤrewindϤäƤseekϤʤ
	# (gzipΥإå եåΤ)
	begin
	  file = open(filename,'w')
	rescue
	  STDERR.print "#{filename}ޤǤ\n"    
	  return nil,nil,"#{filename}ޤǤ(1)"
	end

	file = Zlib::GzipWriter.new(file)
	
	file.write  contents
	file.write  tmp_file.read
	
	file.close
	tmp_file.close

	File.unlink(tmp_filename)

	begin
	  file =  open(filename,'r')
	rescue 
	  STDERR.print "#{filename}ޤǤ\n"    
	  return nil,nil,"#{filename}ޤǤ(2)"
	end
	  

	file = Zlib::GzipReader.new(file)
      else
	tmp_file.close
	file,error = file_change(tmp_filename,filename)
	unless file 
	  return nil,nil,error
	end
      end
    elsif  /^\-INCR/ =~ line
      if file
	file.close
      end
      tmp_file.close

      file,error = file_change(tmp_filename,filename)
      unless file 
	return nil,nil,error
      end

    else
# Thanks: 136
      STDERR.print "threadե˰۾郎ޤdatƤǽ⤤Ǥ\n"
      tmp_file.close
      File.unlink(tmp_filename)
      return file,nil,'threadե˰۾郎ޤdatƤǽ⤤Ǥ'
    end
    return file,num_of_statements,nil
  end


end

module  GetBoardSubject2ch
  include HTTPGetGzip


  def get_board_subject_file(board)
    host = board.get_host
    port = board.get_port
    path = board.get_path
    filename = board.get_filename

    if board.get_dat
      return get_board_subject_file_dat(host,port,path,filename)
    else
      return get_board_subject_file_read_cgi(host,port,path,filename)
    end
  end

  def get_board_subject_file_read_cgi(host,port,path,filename,ls=nil)
    # ls̤ƥ
    if %r!^(.*)(/[^/]+/)$! =~ path
      path2 = $1 + '/test/read.cgi' + $2 + '?raw=0.0'
      if ls 
	path2 += "&ls=#{ls}"
      end
    else
      return get_board_subject_file_(host,port,path,filename,nil)
    end
    file,error=http_get_file(host,port,path2,filename)
    return get_board_subject_file_(host,port,path,filename,file)
  end

  def get_board_subject_file_dat(host,port,path,filename)
    
    path2 = path + 'subject.txt'
    file,error=http_get_file(host,port,path2,filename)
    return get_board_subject_file_(host,port,path,filename,file)
  end

  def get_board_subject_file_(host,port,path,filename,file)
    # Thanks >>8:
    error = nil
    if file == nil
      STDERR.print "subjectեμ˼Ԥޤ\n"

      error = 'subjectեμ˼Ԥޤ'
      if File.exist?(filename)
	STDERR.print "åѤޤ.\n"
	begin
	  file = open( filename, 'r' )
	rescue
	  STDERR.print "#{filename}ޤǤ\n"   
	  return nil,error + " åե #{filename} ޤǤ"   
	end
	begin
	  file = Zlib::GzipReader.new(file)
	rescue  
         # gzipǤʤ
	end
	return file,error +  ' åѤޤ'
      else
	STDERR.print "å⤢ޤ.\n"
      end

      return nil, error + ' å⤢ޤ'
    end

    

    return file,nil

  end

end


module  GetBoardInfo2ch
  include HTTPGetGzip

  def get_board_info(host,port,path)
#     Net::HTTP.start(host,port,$proxy_addr,$proxy_port){ |http|
    Net::HTTP.start(host,port,$connect2ch_config['get_proxy_addr'],$connect2ch_config['get_proxy_port']){ |http|
      response,= http.get(path,nil)

      if response.code == '200'
	return response.body
      else
	return nil
      end
    }
  end

  def parse_board_info_html(body)

    flag = 0
    info = []

    body=NKF::nkf('-ex',body)
    body.each { |line|
      while true
#	line=Kconv::toeuc(line)
#	line=NKF::nkf('-ex',line)
#	p line
	line.strip!
	if /^<B>(.*?)<\/B><BR>(.*)$/i =~  line
	  tmp = 'C ' + $1 +"\n"
	  if 'å' == $1
	    return info
	  elsif 'ޤ££' == $1
	    flag=0
	  else
	    flag=1
	    info << tmp
	  end
	  line = $2
	elsif /^<A HREF=([^> ]*).*?>(.*?)<\/A>(.*)$/i =~ line
	  url = $1
	  board = $2
	  line = $3

	  if url != 'http://www.machibbs.com/' && url != 'http://dempa.gozans.com/'
	    if flag ==1
	      tmp = 'B '
	    elsif flag ==2
	      tmp = 'A ' 
	    end
	    if flag > 0 
#	      tmp1 = $1
#	      tmp2 = $2
#	      tmp2.gsub!(/<br>/i,' ')
#	      board.gsub!(/<br>/i,' ')
	      tmp += url + ' ' + board.gsub(/<br>/i,' ')  + "\n"
	      info << tmp
	    end
	  end
	elsif /^.+?((<B>|<A).*)$/i =~ line
	  line = $1
	else
	  break
	end
      end
    }
    return info
  end

end
